@@ -51,7 +51,6 @@ use OC\HintException;
 use OC\Hooks\PublicEmitter;
 use OC\ServerNotAvailableException;
 use OCA\User_LDAP\Exceptions\ConstraintViolationException;
-use OCA\User_LDAP\Exceptions\NoMoreResults;
 use OCA\User_LDAP\Mapping\AbstractMapping;
 use OCA\User_LDAP\User\Manager;
 use OCA\User_LDAP\User\OfflineUser;
@@ -268,14 +267,7 @@ class Access extends LDAPUtility {
 	 * @throws ServerNotAvailableException
 	 */
 	public function executeRead($cr, $dn, $attribute, $filter, $maxResults) {
-		try {
-			$this->initPagedSearch($filter, $dn, [$attribute], $maxResults, 0);
-		} catch (NoMoreResults $e) {
-			// does not happen, no pagination here since offset is 0, but the
-			// previous call is needed for a potential reset of the state.
-			// Tools would still point out a possible NoMoreResults exception.
-			return false;
-		}
+		$this->initPagedSearch($filter, $dn, [$attribute], $maxResults, 0);
 		$dn = $this->helper->DNasBaseParameter($dn);
 		$rr = @$this->invokeLDAPMethod('read', $cr, $dn, $filter, [$attribute]);
 		if (!$this->ldap->isResource($rr)) {
@@ -956,7 +948,7 @@ class Access extends LDAPUtility {
 
 		array_walk($groupRecords, function ($record) use ($idsByDn) {
 			$newlyMapped = false;
-			$gid = $idsByDn[$record['dn'][0]] ?? null;
+			$gid = $uidsByDn[$record['dn'][0]] ?? null;
 			if ($gid === null) {
 				$gid = $this->dn2ocname($record['dn'][0], null, false, $newlyMapped, $record);
 			}
@@ -1154,12 +1146,7 @@ class Access extends LDAPUtility {
 		}
 
 		//check whether paged search should be attempted
-		try {
-			$pagedSearchOK = $this->initPagedSearch($filter, $base, $attr, (int)$limit, (int)$offset);
-		} catch (NoMoreResults $e) {
-			// beyond last results page
-			return false;
-		}
+		$pagedSearchOK = $this->initPagedSearch($filter, $base, $attr, (int)$limit, (int)$offset);
 
 		$sr = $this->invokeLDAPMethod('search', $cr, $base, $filter, $attr);
 		// cannot use $cr anymore, might have changed in the previous call!
@@ -1449,7 +1436,7 @@ class Access extends LDAPUtility {
 	 * @param bool $allowAsterisk whether in * at the beginning should be preserved
 	 * @return string the escaped string
 	 */
-	public function escapeFilterPart($input, $allowAsterisk = false) {
+	public function escapeFilterPart($input, $allowAsterisk = false): string {
 		$asterisk = '';
 		if ($allowAsterisk && strlen($input) > 0 && $input[0] === '*') {
 			$asterisk = '*';
@@ -1466,7 +1453,7 @@ class Access extends LDAPUtility {
 	 * @param string[] $filters the filters to connect
 	 * @return string the combined filter
 	 */
-	public function combineFilterWithAnd($filters) {
+	public function combineFilterWithAnd($filters): string {
 		return $this->combineFilter($filters, '&');
 	}
 
@@ -2012,7 +1999,6 @@ class Access extends LDAPUtility {
 	 * @param int $offset
 	 * @return bool|true
 	 * @throws ServerNotAvailableException
-	 * @throws NoMoreResults
 	 */
 	private function initPagedSearch(
 		string $filter,
@@ -2044,7 +2030,7 @@ class Access extends LDAPUtility {
 				if (!$this->hasMoreResults()) {
 					// when the cookie is reset with != 0 offset, there are no further
 					// results, so stop.
-					throw new NoMoreResults();
+					return false;
 				}
 			}
 			if ($this->lastCookie !== '' && $offset === 0) {
