@@ -17,10 +17,8 @@ OC.L10N.register(
     "PHP %s or higher is required." : "Se requiere de PHP %s o superior.",
     "PHP with a version lower than %s is required." : "PHP con una versión inferiror a la %s es requerido. ",
     "%sbit or higher PHP required." : "se requiere PHP para %sbit o superior.",
-    "Following databases are supported: %s" : "Las siguientes bases de datos están soportadas: %s",
     "The command line tool %s could not be found" : "No fue posible encontar la herramienta de línea de comando %s",
     "The library %s is not available." : "La biblioteca %s no está disponible. ",
-    "Following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
     "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
     "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerdia. ",
     "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
@@ -79,7 +77,6 @@ OC.L10N.register(
     "Set an admin username." : "Establecer un Usuario administrador",
     "Set an admin password." : "Establecer la contraseña del administrador.",
     "Can't create or write into the data directory %s" : "No es posible crear o escribir en el directorio de datos %s",
-    "Invalid Federated Cloud ID" : "ID Inválido",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
     "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
@@ -162,8 +159,8 @@ OC.L10N.register(
     "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Por lo general los permisos se pueden corregir al darle al servidor web acceso de escritura al directorio raíz. Por favor ve %s.",
     "Setting locale to %s failed" : "Se presentó una falla al establecer la regionalización a  %s",
     "Please install one of these locales on your system and restart your webserver." : "Por favor instala uno de las siguientes configuraciones locales en tu sistema y reinicia tu servidor web",
-    "Please ask your server administrator to install the module." : "Por favor solicita a tu adminsitrador la instalación del módulo. ",
     "PHP module %s not installed." : "El módulo de PHP %s no está instalado. ",
+    "Please ask your server administrator to install the module." : "Por favor solicita a tu adminsitrador la instalación del módulo. ",
     "PHP setting \"%s\" is not set to \"%s\"." : "El ajuste PHP \"%s\" no esta establecido a \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "El cambiar este ajuste del archivo php.ini hará que Nextcloud corra de nuevo.",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está establecido como \"%s\" en lugar del valor esperado de \"0\"",
@@ -176,8 +173,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Por favor solicita al administrador reiniciar el servidor web. ",
     "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9",
     "Please upgrade your database version" : "Por favor actualiza tu versión de la base de datos",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
     "Your data directory is readable by other users" : "Tu direcctorio data puede ser leído por otros usuarios",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
     "Your data directory must be an absolute path" : "Tu directorio data debe ser una ruta absoluta",
     "Check the value of \"datadirectory\" in your configuration" : "Verifica el valor de \"datadirectory\" en tu configuración",
     "Your data directory is invalid" : "Tu directorio de datos es inválido",
@@ -188,30 +185,8 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
-    "Create" : "Crear",
-    "Change" : "Cambiar",
-    "Delete" : "Borrar",
-    "Share" : "Compartir",
-    "Overview" : "Generalidades",
-    "Basic settings" : "Configuraciones  básicas",
-    "Sharing" : "Compartiendo",
-    "Security" : "Seguridad",
-    "Personal info" : "Información personal",
-    "Unlimited" : "Ilimitado",
-    "Verifying" : "Verficando",
-    "Verifying …" : "Verficando ...",
-    "Verify" : "Verificar",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "Se presentó una falla al compartir %s, porque el backend no permite elementos compartidos de tipo %i",
-    "Sharing %s failed, because the file does not exist" : "Se presentó una falla al compartir %s porque el archivo no existe",
-    "Sharing %s failed, because you can not share with yourself" : "Se presentó una falla al compartir %s, porque no puedes compartir contigo mismo",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Necesitas proporcionar una contraseña para crear una liga pública, sólo se permiten ligas protegidas. ",
-    "Sharing %s failed, because sharing with links is not allowed" : "Se presentó una falla al compartir %s porque no está permitido compartir con ligas",
-    "Not allowed to create a federated share with the same user" : "No está permitido crear un elemento compartido con el mismo usuario",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "No ha sido posible establecer la fecha de expiración. Los recursos compartidos no pueden expirar después de %s tras haber sido compartidos",
-    "Cannot set expiration date. Expiration date is in the past" : "No ha sido posible establecer la fecha de expiración. La fecha de expiración ya ha pasado",
-    "Sharing failed, because the user %s is the original sharer" : "Se presentó una falla al compartir, porque el usuario %s es quien compartió originalmente",
-    "Sharing %s failed, because resharing is not allowed" : "Falla al compartir %s debído a que no se permite volver a compartir",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Se presentó una falla al compartir %s porque el archivo no se encontró en el caché de archivos",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio de las aplicaciones o deshabilitando la appstore en el archivo config. Por favor ve %s"
+    "Following databases are supported: %s" : "Las siguientes bases de datos están soportadas: %s",
+    "Following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
+    "Invalid Federated Cloud ID" : "ID Inválido"
 },
 "nplurals=2; plural=(n != 1);");
