@@ -3,13 +3,14 @@ OC.L10N.register(
     {
     "Cannot write into \"config\" directory!" : "Impossibile scrivere nella cartella \"config\"!",
     "This can usually be fixed by giving the webserver write access to the config directory" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"config\"",
-    "See %s" : "Vedi %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "O, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true.",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella di configurazione. Vedi %s",
+    "See %s" : "Vedi %s",
+    "This can usually be fixed by giving the webserver write access to the config directory." : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"config\".",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true. Vedi %s",
-    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "I file dell'applicazione %1$s non sono stati sostituiti correttamente. Assicurati che sia una versione compatibile con il server.",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "I file dell'applicazione %1$s non sono stati sostituiti correttamente. Assicurati che sia una versione compatibile con il server.",
     "Sample configuration detected" : "Configurazione di esempio rilevata",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "È stato rilevato che la configurazione di esempio è stata copiata. Ciò può compromettere la tua installazione e non è supportato. Leggi la documentazione prima di modificare il file config.php",
+    "Other activities" : "Altre attività",
     "%1$s and %2$s" : "%1$s e %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
@@ -17,19 +18,35 @@ OC.L10N.register(
     "Education Edition" : "Edizione didattica",
     "Enterprise bundle" : "Pacchetto Enterprise",
     "Groupware bundle" : "Pacchetto Groupware",
+    "Hub bundle" : "Pacchetto Hub",
     "Social sharing bundle" : "Pacchetto Social sharing",
     "PHP %s or higher is required." : "Richiesto PHP %s o superiore",
     "PHP with a version lower than %s is required." : "Richiesta una versione di PHP minore di %s.",
     "%sbit or higher PHP required." : "Richiesto PHP %sbit o superiore.",
-    "Following databases are supported: %s" : "I seguenti database sono supportati: %s",
+    "The following architectures are supported: %s" : "Sono supportate le seguenti architetture: %s",
+    "The following databases are supported: %s" : "I seguenti database sono supportati: %s",
     "The command line tool %s could not be found" : "Lo strumento da riga di comando %s non è stato trovato",
     "The library %s is not available." : "La libreria %s non è disponibile.",
     "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Richiesta una versione della libreria %1$s maggiore di %2$s - versione disponibile %3$s.",
     "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Richiesta una versione della libreria %1$s minore di %2$s - versione disponibile %3$s.",
-    "Following platforms are supported: %s" : "Sono supportate le seguenti piattaforme: %s",
+    "The following platforms are supported: %s" : "Le seguenti piattaforme sono supportate: %s",
     "Server version %s or higher is required." : "È richiesta la versione %s o successiva.",
     "Server version %s or lower is required." : "È richiesta la versione %s o precedente.",
+    "Logged in user must be an admin or sub admin" : "L'utente che ha eseguito l'accesso deve essere un amministratore o sub-amministratore",
     "Logged in user must be an admin" : "L'utente che ha eseguito l'accesso deve essere un amministratore ",
+    "Wiping of device %s has started" : "La cancellazione del dispositivo %s è iniziata",
+    "Wiping of device »%s« has started" : "La cancellazione del dispositivo «%s» è iniziata",
+    "»%s« started remote wipe" : "«%s» ha iniziato la cancellazione remota",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Il dispositivo o l'applicazione «%s» ha iniziato il processo di cancellazione remota. Riceverai un'altra email al termine del processo ",
+    "Wiping of device %s has finished" : "La cancellazione del dispositivo %s è terminata",
+    "Wiping of device »%s« has finished" : "La cancellazione del dispositivo «%s» è terminata",
+    "»%s« finished remote wipe" : "«%s» ha terminato la cancellazione remota",
+    "Device or application »%s« has finished the remote wipe process." : "Il dispositivo o l'applicazione «%s» ha terminato il processo di cancellazione remota.",
+    "Remote wipe started" : "Cancellazione remota avviata",
+    "A remote wipe was started on device %s" : "Una cancellazione remota è stata avviata sul dispositivo %s",
+    "Remote wipe finished" : "Cancellazione remota terminata",
+    "The remote wipe on %s has finished" : "La cancellazione remota su %s è terminata",
+    "Authentication" : "Autenticazione",
     "Unknown filetype" : "Tipo di file sconosciuto",
     "Invalid image" : "Immagine non valida",
     "Avatar image is not square" : "L'immagine personale non è quadrata",
@@ -52,7 +69,11 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n minuto fa","%n minuti fa"],
     "in a few seconds" : "tra pochi secondi",
     "seconds ago" : "secondi fa",
+    "Empty file" : "File vuoto",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Il modulo con ID: %s non esiste. Abilitalo nelle impostazioni delle applicazioni o contatta il tuo amministratore.",
+    "File already exists" : "Il file esiste già",
+    "Failed to create file from template" : "Impossibile creare un file dal modello",
+    "Templates" : "Modelli",
     "File name is a reserved word" : "Il nome del file è una parola riservata",
     "File name contains at least one invalid character" : "Il nome del file contiene almeno un carattere non valido",
     "File name is too long" : "Il nome del file è troppo lungo",
@@ -68,30 +89,16 @@ OC.L10N.register(
     "Log out" : "Esci",
     "Users" : "Utenti",
     "Unknown user" : "Utente sconosciuto",
-    "Create" : "Crea",
-    "Change" : "Modifica",
-    "Delete" : "Elimina",
-    "Share" : "Condividi",
-    "Overview" : "Riepilogo",
-    "Basic settings" : "Impostazioni di base",
-    "Sharing" : "Condivisione",
-    "Security" : "Sicurezza",
-    "Groupware" : "Groupware",
     "Additional settings" : "Impostazioni aggiuntive",
-    "Personal info" : "Informazioni personali",
-    "Mobile & desktop" : "Mobile e desktop",
-    "Unlimited" : "Illimitato",
-    "Verifying" : "Verifica",
-    "Verifying …" : "Verifica in corso...",
-    "Verify" : "Verifica",
     "%s enter the database username and name." : "%s digita il nome utente e il nome del database.",
     "%s enter the database username." : "%s digita il nome utente del database.",
     "%s enter the database name." : "%s digita il nome del database.",
     "%s you may not use dots in the database name" : "%s non dovresti utilizzare punti nel nome del database",
+    "MySQL username and/or password not valid" : "Nome utente e/o password di MySQL non validi",
+    "You need to enter details of an existing account." : "Devi inserire i dettagli di un account esistente.",
     "Oracle connection could not be established" : "La connessione a Oracle non può essere stabilita",
     "Oracle username and/or password not valid" : "Nome utente e/o password di Oracle non validi",
     "PostgreSQL username and/or password not valid" : "Nome utente e/o password di PostgreSQL non validi",
-    "You need to enter details of an existing account." : "Devi inserire i dettagli di un account esistente.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non è supportato e %s non funzionerà correttamente su questa piattaforma. Usalo a tuo rischio!",
     "For the best results, please consider using a GNU/Linux server instead." : "Per avere il risultato migliore, prendi in considerazione l'utilizzo di un server GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Sembra che questa istanza di %s sia in esecuzione in un ambiente PHP a 32 bit e che open_basedir sia stata configurata in php.ini. Ciò comporterà problemi con i file più grandi di 4 GB ed è altamente sconsigliato.",
@@ -99,37 +106,15 @@ OC.L10N.register(
     "Set an admin username." : "Imposta un nome utente di amministrazione.",
     "Set an admin password." : "Imposta una password di amministrazione.",
     "Can't create or write into the data directory %s" : "Impossibile creare o scrivere nella cartella dei dati %s",
-    "Invalid Federated Cloud ID" : "ID di cloud federata non valido",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "Condivisione di %s non riuscita, poiché il motore non consente condivisioni del tipo %i",
-    "Sharing %s failed, because the file does not exist" : "Condivisione di %s non riuscita, poiché il file non esiste",
-    "You are not allowed to share %s" : "Non ti è consentito condividere %s",
-    "Sharing %s failed, because you can not share with yourself" : "Condivisione di %s non riuscita, poiché non puoi condividere con te stesso",
-    "Sharing %1$s failed, because the user %2$s does not exist" : "Condivisione di %1$s non riuscita, poiché l'utente %2$s non esiste",
-    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Condivisione di %1$s non riuscita, poiché l'utente %2$s non appartiene ad alcun gruppo di cui %3$s è membro",
-    "Sharing %1$s failed, because this item is already shared with %2$s" : "Condivisione di %1$s non riuscita, poiché l'oggetto è già condiviso con %2$s",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Condivisione di %1$s non riuscita, poiché l'oggetto è già condiviso con l'utente %2$s",
-    "Sharing %1$s failed, because the group %2$s does not exist" : "Condivisione di %1$s non riuscita, poiché il gruppo %2$s non esiste",
-    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Condivisione di %1$s non riuscita, poiché %2$s non appartiene al gruppo %3$s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Devi fornire una password per creare un collegamento pubblico, sono consentiti solo i collegamenti protetti",
-    "Sharing %s failed, because sharing with links is not allowed" : "Condivisione di %s non riuscita, poiché i collegamenti non sono consentiti",
-    "Not allowed to create a federated share with the same user" : "Non è consentito creare una condivisione federata con lo stesso utente",
-    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "La condivisione di %1$s non è riuscita, impossibile trovare %2$s, è probabile che il server non sia al momento raggiungibile.",
-    "Share type %1$s is not valid for %2$s" : "Il tipo di condivisione %1$s non è valido per %2$s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Impossibile impostare la data di scadenza. Le condivisioni non possono scadere più tardi di %s dalla loro attivazione",
-    "Cannot set expiration date. Expiration date is in the past" : "Impossibile impostare la data di scadenza. La data di scadenza è nel passato.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Il motore di condivisione %s deve implementare l'interfaccia OCP\\Share_Backend",
     "Sharing backend %s not found" : "Motore di condivisione %s non trovato",
     "Sharing backend for %s not found" : "Motore di condivisione di %s non trovato",
-    "Sharing failed, because the user %s is the original sharer" : "Condivisione non riuscita, poiché l'utente %s ha condiviso in origine",
-    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Condivisione di %1$s non riuscita, poiché i permessi superano quelli accordati a %2$s",
-    "Sharing %s failed, because resharing is not allowed" : "Condivisione di %s non riuscita, poiché la ri-condivisione non è consentita",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Condivisione di %1$s non riuscita, poiché il motore di condivisione per %2$s non riesce a trovare la sua fonte",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Condivisione di %s non riuscita, poiché il file non è stato trovato nella cache",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha condiviso «%2$s» con te e vuole aggiungere:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s ha condiviso «%2$s» con te e vuole aggiungere",
     "»%s« added a note to a file shared with you" : "«%s» ha aggiunto una nota a un file condiviso con te",
     "Open »%s«" : "Apri «%s»",
     "%1$s via %2$s" : "%1$s tramite %2$s",
+    "You are not allowed to share %s" : "Non ti è consentito condividere %s",
     "Can’t increase permissions of %s" : "Impossibile aumentare i permessi di %s",
     "Files can’t be shared with delete permissions" : "I file non possono essere condivisi con permessi di eliminazione",
     "Files can’t be shared with create permissions" : "I file non possono essere condivisi con permessi di creazione",
@@ -185,10 +170,12 @@ OC.L10N.register(
     "Oct." : "Ott.",
     "Nov." : "Nov.",
     "Dec." : "Dic.",
+    "The user limit has been reached and the user was not created." : "È stato raggiunto il limite di utenti e l'utente non è stato creato.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Solo i seguenti caratteri sono consentiti in un nome utente: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
     "A valid username must be provided" : "Deve essere fornito un nome utente valido",
     "Username contains whitespace at the beginning or at the end" : "Il nome utente contiene spazi all'inizio o alla fine",
     "Username must not consist of dots only" : "Il nome utente non può consistere di soli punti",
+    "Username is invalid because files already exist for this user" : "Il nome utente non è valido poiché esiste già per questo utente",
     "A valid password must be provided" : "Deve essere fornita una password valida",
     "The username is already being used" : "Il nome utente è già utilizzato",
     "Could not create user" : "Impossibile creare l'utente",
@@ -203,15 +190,16 @@ OC.L10N.register(
     "Token expired. Please reload page." : "Token scaduto. Ricarica la pagina.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nessun driver di database (sqlite, mysql o postgresql) installato",
     "Cannot write into \"config\" directory" : "Impossibile scrivere nella cartella \"config\"",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella di configurazione. Vedi %s",
     "Cannot write into \"apps\" directory" : "Impossibile scrivere nella cartella \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella delle applicazioni o disabilitando il negozio di applicazioni nel file di configurazione. Vedi %s",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Questo può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"apps\" o disabilitando il negozio di applicazioni nel file di configurazione.",
     "Cannot create \"data\" directory" : "Impossibile creare la cartella \"data\"",
     "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella radice. Vedi %s",
     "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "I permessi possono essere normalmente corretti fornendo al server web accesso in scrittura alla cartella radice. Vedi %s.",
     "Setting locale to %s failed" : "L'impostazione della localizzazione a %s non è riuscita",
     "Please install one of these locales on your system and restart your webserver." : "Installa una delle seguenti localizzazioni sul tuo sistema e riavvia il server web.",
-    "Please ask your server administrator to install the module." : "Chiedi all'amministratore del tuo server di installare il modulo.",
     "PHP module %s not installed." : "Il modulo PHP %s non è installato.",
+    "Please ask your server administrator to install the module." : "Chiedi all'amministratore del tuo server di installare il modulo.",
     "PHP setting \"%s\" is not set to \"%s\"." : "L'impostazione \"%s\" di PHP non è configurata a \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Per eseguire nuovamente Nextcloud, modificare questa impostazione nel file php.ini",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload è impostata a \"%s\" invece del valore atteso \"0\"",
@@ -224,8 +212,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Chiedi all'amministratore di riavviare il server web.",
     "PostgreSQL >= 9 required" : "Richiesto PostgreSQL >= 9",
     "Please upgrade your database version" : "Aggiorna la versione del tuo database",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Modifica i permessi in 0770 in modo tale che la cartella non sia leggibile dagli altri utenti.",
     "Your data directory is readable by other users" : "La cartella dei dati è leggibile dagli altri utenti",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Modifica i permessi in 0770 in modo tale che la cartella non sia leggibile dagli altri utenti.",
     "Your data directory must be an absolute path" : "La cartella dei dati deve essere un percorso assoluto",
     "Check the value of \"datadirectory\" in your configuration" : "Controlla il valore di \"datadirectory\" nella tua configurazione",
     "Your data directory is invalid" : "La cartella dei dati non è valida",
@@ -241,41 +229,8 @@ OC.L10N.register(
     "Storage connection error. %s" : "Errore di connessione all'archiviazione. %s",
     "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
     "Storage connection timeout. %s" : "Timeout di connessione all'archiviazione. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Richiesta una versione della libreria %s maggiore di %s - versione disponibile %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Richiesta una versione della libreria %s minore di %s - versione disponibile %s.",
-    "Personal" : "Personale",
-    "Admin" : "Admin",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Encryption" : "Cifratura",
-    "Tips & tricks" : "Suggerimenti e trucchi",
-    "DB Error: \"%s\"" : "Errore DB: \"%s\"",
-    "Offending command was: \"%s\"" : "Il comando non consentito era: \"%s\"",
-    "Offending command was: \"%s\", name: %s, password: %s" : "Il comando non consentito era: \"%s\", nome: %s, password: %s",
-    "Sharing %s failed, because the user %s does not exist" : "Condivisione di %s non riuscita, poiché l'utente %s non esiste",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Condivisione di %s non riuscita, poiché l'utente %s non appartiene ad alcun gruppo di cui %s è membro",
-    "Sharing %s failed, because this item is already shared with %s" : "Condivisione di %s non riuscita, poiché l'oggetto è già condiviso con %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Condivisione di %s non riuscita, poiché l'oggetto è già condiviso con l'utente %s",
-    "Sharing %s failed, because the group %s does not exist" : "Condivisione di %s non riuscita, poiché il gruppo %s non esiste",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Condivisione di %s non riuscita, poiché %s non appartiene al gruppo %s",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "La condivisione di %s non è riuscita, impossibile trovare %s, è probabile che il server non sia al momento raggiungibile.",
-    "Share type %s is not valid for %s" : "Il tipo di condivisione %s non è valido per %s",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Impostazione permessi per %s non riuscita, poiché i permessi superano i permessi accordati a %s",
-    "Setting permissions for %s failed, because the item was not found" : "Impostazione permessi per %s non riuscita, poiché l'elemento non è stato trovato",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "Impossibile cancellare la data di scadenza. Le condivisioni devono avere una data di scadenza.",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Condivisione di %s non riuscita, poiché i permessi superano quelli accordati a %s",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Condivisione di %s non riuscita, poiché il motore di condivisione per %s non riesce a trovare la sua fonte",
-    "Cannot increase permissions of %s" : "Impossibile aumentare i permessi di %s",
-    "Files can't be shared with delete permissions" : "I file non possono essere condivisi con permessi di eliminazione",
-    "Files can't be shared with create permissions" : "I file non possono essere condivisi con permessi di creazione",
-    "Cannot set expiration date more than %s days in the future" : "Impossibile impostare la data di scadenza a più di %s giorni nel futuro",
-    "%s shared »%s« with you" : "%s ha condiviso «%s» con te",
-    "%s shared »%s« with you." : "%s ha condiviso «%s» con te.",
-    "%s via %s" : "%s tramite %s",
-    "No app name specified" : "Il nome dell'applicazione non è specificato",
-    "App '%s' could not be installed!" : "L'applicazione '%s' non può essere installata!",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'applicazione \"%s\" non può essere installata poiché le seguenti dipendenze non sono soddisfatte: %s",
-    "Sync clients" : "Client di sincronizzazione",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "ID \"%s\" già utilizzato dal fornitore della federazione cloud \"%s\""
+    "Following databases are supported: %s" : "I seguenti database sono supportati: %s",
+    "Following platforms are supported: %s" : "Sono supportate le seguenti piattaforme: %s",
+    "Invalid Federated Cloud ID" : "ID di cloud federata non valido"
 },
 "nplurals=2; plural=(n != 1);");
